@@ -133,7 +133,7 @@ sub load {
       $data = $ZoneMinder::Database::dbh->selectrow_hashref("SELECT * FROM `$table` WHERE `$primary_key`=?", {}, $$self{$primary_key});
       if ( !$data ) {
         if ( $ZoneMinder::Database::dbh->errstr ) {
-          Error( "Failure to load Object record for $$self{$primary_key}: Reason: " . $ZoneMinder::Database::dbh->errstr );
+          Error( "Failure to load Object record for $type id:$$self{$primary_key}: Reason: " . $ZoneMinder::Database::dbh->errstr );
         } else {
           Debug("No Results Loading $type from $table WHERE $primary_key = $$self{$primary_key}");
         } # end if
@@ -173,7 +173,7 @@ sub lock_and_load {
   my $data = $ZoneMinder::Database::dbh->selectrow_hashref("SELECT * FROM `$table` WHERE `$primary_key`=? FOR UPDATE", {}, $$self{$primary_key});
   if ( ! $data ) {
     if ( $ZoneMinder::Database::dbh->errstr ) {
-      Error("Failure to load Object record for $$self{$primary_key}: Reason: ".$ZoneMinder::Database::dbh->errstr);
+      Error("Failure to load Object record for $type id:$$self{$primary_key}: Reason: ".$ZoneMinder::Database::dbh->errstr);
     } else {
       Debug("No Results Lock and Loading $type from $table WHERE $primary_key = $$self{$primary_key}");
     } # end if
