@@ -122,14 +122,16 @@ Event::Event(
     video_incomplete_file = "incomplete."+container;
   }
 
+  std::string now_str = SystemTimePointToMysqlString(now);
+
   std::string sql = stringtf(
                       "INSERT INTO `Events` "
                       "( `MonitorId`, `StorageId`, `Name`, `StartDateTime`, `Width`, `Height`, `Cause`, `Notes`, `StateId`, `Orientation`, `Videoed`, `DefaultVideo`, `SaveJPEGs`, `Scheme`, `Latitude`, `Longitude` )"
                       " VALUES "
-                      "( %d, %d, 'New Event', from_unixtime(%" PRId64 "), %u, %u, '%s', '%s', %d, %d, %d, '%s', %d, '%s', '%f', '%f' )",
+                      "( %d, %d, 'New Event', '%s', %u, %u, '%s', '%s', %d, %d, %d, '%s', %d, '%s', '%f', '%f' )",
                       monitor->Id(),
                       storage->Id(),
-                      static_cast<int64>(std::chrono::system_clock::to_time_t(start_time)),
+                      now_str.c_str(),
                       monitor->Width(),
                       monitor->Height(),
                       cause.c_str(),
@@ -147,6 +149,40 @@ Event::Event(
     id = zmDbDoInsert(sql);
   } while (!id and !zm_terminate);
 
+  /* None of these are crucial, and are simple when done as individual transactions */
+  sql = stringtf("INSERT INTO `Events_Hour` (EventId,MonitorId,StartDateTime,DiskSpace)"
+      " VALUES (%" PRId64 ",%u,'%s',NULL)",
+      id, monitor->Id(), now_str.c_str());
+  dbQueue.push(std::move(sql));
+  sql = stringtf("INSERT INTO `Events_Day` (EventId,MonitorId,StartDateTime,DiskSpace)"
+      " VALUES (%" PRId64 ",%u,'%s',NULL)",
+      id, monitor->Id(), now_str.c_str());
+  dbQueue.push(std::move(sql));
+  sql = stringtf("INSERT INTO `Events_Week` (EventId,MonitorId,StartDateTime,DiskSpace)"
+      " VALUES (%" PRId64 ",%u,'%s',NULL)",
+      id, monitor->Id(), now_str.c_str());
+  dbQueue.push(std::move(sql));
+  sql = stringtf("INSERT INTO `Events_Month` (EventId,MonitorId,StartDateTime,DiskSpace)"
+      " VALUES (%" PRId64 ",%u,'%s',NULL)",
+      id, monitor->Id(), now_str.c_str());
+  dbQueue.push(std::move(sql));
+  /*
+  sql = stringtf("INSERT INTO `Events_Year` (EventId,MonitorId,StartDateTime,DiskSpace)"
+      " VALUES (%" PRId64 ",%u,'%s',NULL)",
+      id, monitor->Id(), now_str.c_str());
+  dbQueue.push(std::move(sql));
+  */
+  sql = stringtf("INSERT INTO Event_Summaries "
+      "(MonitorId,HourEvents,DayEvents,WeekEvents,MonthEvents,TotalEvents)"
+      " VALUES (%u,1,1,1,1,1) ON DUPLICATE KEY UPDATE"
+      " HourEvents = COALESCE(HourEvents,0)+1,"
+      " DayEvents = COALESCE(DayEvents,0)+1,"
+      " WeekEvents = COALESCE(WeekEvents,0)+1,"
+      " MonthEvents = COALESCE(MonthEvents,0)+1,"
+      " TotalEvents = COALESCE(TotalEvents,0)+1",
+      monitor->Id());
+  dbQueue.push(std::move(sql));
+
   thread_ = std::thread(&Event::Run, this);
 }
 
@@ -731,17 +767,27 @@ void Event::Run() {
   // The idea is to process the queue no matter what so that all packets get processed.
   // We only break if the queue is empty
   while (!terminate_ and !zm_terminate) {
-    ZMLockedPacket *packet_lock = packetqueue->get_packet_no_wait(packetqueue_it);
-    if (packet_lock) {
-      std::shared_ptr<ZMPacket> packet = packet_lock->packet_;
+    ZMPacketLock packet_lock = packetqueue->get_packet_no_wait(packetqueue_it);
+    std::shared_ptr<ZMPacket> packet = packet_lock.packet_;
+    if (packet) {
       if (!packet->decoded) {
-        delete packet_lock;
+        Debug(1, "Not decoded");
+        packet_lock.unlock();
         // Stay behind decoder
         Microseconds sleep_for = Microseconds(ZM_SAMPLE_RATE);
         Debug(4, "Sleeping for %" PRId64 "us", int64(sleep_for.count()));
         std::this_thread::sleep_for(sleep_for);
         continue;
       }
+      if (!packet->analyzed) {
+        Debug(1, "Not analyzed");
+        packet_lock.unlock();
+        // Stay behind ai
+        Microseconds sleep_for = Microseconds(ZM_SAMPLE_RATE);
+        Debug(1, "Sleeping for %" PRId64 "us", int64(sleep_for.count()));
+        std::this_thread::sleep_for(sleep_for);
+        continue;
+      }
 
       Debug(1, "Adding packet %d", packet->image_index);
       this->AddPacket_(packet);
@@ -761,10 +807,8 @@ void Event::Run() {
           packet->analysis_image = nullptr;
         }
       } // end if packet->image
-      Debug(1, "Deleting packet lock");
-      delete packet_lock;
       // Important not to increment it until after we are done with the packet because clearPackets checks for iterators pointing to it.
-      packetqueue->increment_it(packetqueue_it);
+      packetqueue->increment_it(packetqueue_it, true);
     } else {
       if (terminate_ or zm_terminate) return;
       usleep(10000);
