@@ -206,7 +206,7 @@ class Image {
     const size_t buffer_size);
   void Assign(const Image &image);
   bool Assign(const AVFrame *frame);
-  bool Assign(const AVFrame *frame, SwsContext *convert_context, AVFrame *temp_frame);
+  bool Assign(const AVFrame *frame, SwsContext *convert_context);
   void AssignDirect(
     const unsigned int p_width,
     const unsigned int p_height,
@@ -264,7 +264,7 @@ class Image {
   static Image *Merge( unsigned int n_images, Image *images[], double weight );
   static Image *Highlight(unsigned int n_images, Image *images[], Rgb threshold = kRGBBlack, Rgb ref_colour = kRGBRed);
   //Image *Delta( const Image &image ) const;
-  void Delta( const Image &image, Image* targetimage) const;
+  bool Delta( const Image &image, Image* targetimage) const;
 
   const Vector2 centreCoord(const char *text, const int size) const;
   void MaskPrivacy( const unsigned char *p_bitmask, const Rgb pixel_colour=0x00222222 );
