@@ -203,17 +203,17 @@ void RtpSource::updateRtcpData(
   timeval ntpTime = zm::chrono::duration_cast<timeval>(
                       Seconds(ntpTimeSecs) + Microseconds((Microseconds::period::den * (ntpTimeFrac >> 16)) / (1 << 16)));
 
-  Debug(5, "ntpTime: %ld.%06ld, rtpTime: %x", ntpTime.tv_sec, ntpTime.tv_usec, rtpTime);
+  Debug(5, "ntpTime: %jd.%06ld, rtpTime: %x", static_cast<intmax_t>(ntpTime.tv_sec), ntpTime.tv_usec, rtpTime);
 
   if ( mBaseTimeNtp.tv_sec == 0 ) {
     mBaseTimeReal = std::chrono::system_clock::now();
     mBaseTimeNtp = ntpTime;
     mBaseTimeRtp = rtpTime;
   } else if ( !mRtpClock ) {
-    Debug(5, "lastSrNtpTime: %ld.%06ld, rtpTime: %x"
-          "ntpTime: %ld.%06ld, rtpTime: %x",
-          mLastSrTimeNtp.tv_sec, mLastSrTimeNtp.tv_usec, rtpTime,
-          ntpTime.tv_sec, ntpTime.tv_usec, rtpTime);
+    Debug(5, "lastSrNtpTime: %jd.%06ld, rtpTime: %x"
+          "ntpTime: %jd.%06ld, rtpTime: %x",
+          static_cast<intmax_t>(mLastSrTimeNtp.tv_sec), mLastSrTimeNtp.tv_usec, rtpTime,
+          static_cast<intmax_t>(ntpTime.tv_sec), ntpTime.tv_usec, rtpTime);
 
     FPSeconds diffNtpTime =
       zm::chrono::duration_cast<Microseconds>(ntpTime) - zm::chrono::duration_cast<Microseconds>(mBaseTimeNtp);
