@@ -11,6 +11,12 @@
 
 #include "zm_rtsp_server_fifo_source.h"
 
+// Forward declarations
+namespace xop {
+  class H264Source;
+  class H265Source;
+}
+
 #if HAVE_RTSP_SERVER
 
 class ZoneMinderFifoVideoSource: public ZoneMinderFifoSource {
@@ -21,6 +27,10 @@ class ZoneMinderFifoVideoSource: public ZoneMinderFifoSource {
   int setWidth(int width) { return m_width=width; };
   int setHeight(int height) { return m_height=height; };
 
+  // Set xop sources for SPS/PPS updates
+  void setH264Source(xop::H264Source *source) { m_h264Source = source; }
+  void setH265Source(xop::H265Source *source) { m_h265Source = source; }
+
   ZoneMinderFifoVideoSource(
     std::shared_ptr<xop::RtspServer>& rtspServer,
     xop::MediaSessionId sessionId,
@@ -33,6 +43,8 @@ class ZoneMinderFifoVideoSource: public ZoneMinderFifoSource {
  protected:
   int m_width;
   int m_height;
+  xop::H264Source *m_h264Source = nullptr;
+  xop::H265Source *m_h265Source = nullptr;
 };
 #endif // HAVE_RTSP_SERVER
 
