@@ -7,10 +7,6 @@ if (!empty($_REQUEST['task'])) {
   $task = $_REQUEST['task'];
   
   if ($task == 'query') {
-    if (!canView('Monitors')) {
-      ajaxError('Insufficient permissions for user '.$user->Username());
-      return;
-    }
     $data = queryRequest();
     ajaxResponse($data);
     return;
@@ -145,7 +141,7 @@ function queryRequest() {
   }
   
   // Build SQL query
-  $sql = 'SELECT M.*, S.*, E.*
+  $sql = 'SELECT M.*, S.*, E.*, (SELECT Name FROM Manufacturers WHERE Manufacturers.Id=M.ManufacturerId) AS Manufacturer, (SELECT Name FROM Models where Models.Id=M.ModelId) AS Model
     FROM Monitors AS M
     LEFT JOIN Monitor_Status AS S ON S.MonitorId=M.Id 
     LEFT JOIN Event_Summaries AS E ON E.MonitorId=M.Id 
@@ -293,6 +289,8 @@ function queryRequest() {
     $row['Name'] = validHtmlStr($monitor['Name']);
     $row['Function'] = $monitor['Function'];
     $row['Enabled'] = $monitor['Enabled'];
+    $row['Manufacturer'] = $monitor['Manufacturer'];
+    $row['Model'] = $monitor['Model'];
     $row['Sequence'] = isset($monitor['Sequence']) ? $monitor['Sequence'] : 0;
     
     // Status
@@ -325,11 +323,50 @@ function queryRequest() {
       $row['Storage'] = '';
     }
     
-    // Event counts
-    $eventCounts = array('Total', 'Hour', 'Day', 'Week', 'Month', 'Archived');
-    foreach ($eventCounts as $period) {
+    // Event counts with filter querystrings
+    $eventCounts = array(
+      'Total' => array(
+        'filter' => array('Query' => array('terms' => array()))
+      ),
+      'Hour' => array(
+        'filter' => array('Query' => array('terms' => array(
+          array('cnj' => 'and', 'attr' => 'StartDateTime', 'op' => '>=', 'val' => '-1 hour')
+        )))
+      ),
+      'Day' => array(
+        'filter' => array('Query' => array('terms' => array(
+          array('cnj' => 'and', 'attr' => 'StartDateTime', 'op' => '>=', 'val' => '-1 day')
+        )))
+      ),
+      'Week' => array(
+        'filter' => array('Query' => array('terms' => array(
+          array('cnj' => 'and', 'attr' => 'StartDateTime', 'op' => '>=', 'val' => '-7 day')
+        )))
+      ),
+      'Month' => array(
+        'filter' => array('Query' => array('terms' => array(
+          array('cnj' => 'and', 'attr' => 'StartDateTime', 'op' => '>=', 'val' => '-1 month')
+        )))
+      ),
+      'Archived' => array(
+        'filter' => array('Query' => array('terms' => array(
+          array('cnj' => 'and', 'attr' => 'Archived', 'op' => '=', 'val' => '1')
+        )))
+      )
+    );
+    
+    foreach ($eventCounts as $period => $eventCount) {
       $row[$period.'Events'] = (int)$monitor[$period.'Events'];
       $row[$period.'EventDiskSpace'] = human_filesize($monitor[$period.'EventDiskSpace']);
+      
+      // Generate filter querystring for this period and monitor
+      $filter = addFilterTerm(
+        $eventCount['filter'],
+        count($eventCount['filter']['Query']['terms']),
+        array('cnj' => 'and', 'attr' => 'Monitor', 'op' => '=', 'val' => $monitor['Id'])
+      );
+      parseFilter($filter);
+      $row[$period.'FilterQuery'] = $filter['querystring'];
     }
     
     // Zone count
@@ -414,11 +451,55 @@ function queryRequest() {
                        round($footer_totals['total_analysis_fps'], 2).' fps',
     'total_zones' => $footer_totals['total_zones']
   );
-  
-  // Add formatted event totals to footer
+
+  // Build filter querystrings for footer event totals (matching header behavior)
+  $eventCountsFooter = array(
+    'Total' => array(
+      'filter' => array('Query' => array('terms' => array()))
+    ),
+    'Hour' => array(
+      'filter' => array('Query' => array('terms' => array(
+        array('cnj' => 'and', 'attr' => 'StartDateTime', 'op' => '>=', 'val' => '-1 hour')
+      )))
+    ),
+    'Day' => array(
+      'filter' => array('Query' => array('terms' => array(
+        array('cnj' => 'and', 'attr' => 'StartDateTime', 'op' => '>=', 'val' => '-1 day')
+      )))
+    ),
+    'Week' => array(
+      'filter' => array('Query' => array('terms' => array(
+        array('cnj' => 'and', 'attr' => 'StartDateTime', 'op' => '>=', 'val' => '-7 day')
+      )))
+    ),
+    'Month' => array(
+      'filter' => array('Query' => array('terms' => array(
+        array('cnj' => 'and', 'attr' => 'StartDateTime', 'op' => '>=', 'val' => '-1 month')
+      )))
+    ),
+    'Archived' => array(
+      'filter' => array('Query' => array('terms' => array(
+        array('cnj' => 'and', 'attr' => 'Archived', 'op' => '=', 'val' => '1')
+      )))
+    )
+  );
+
+  // Add formatted event totals to footer with filter querystrings
   foreach (array('Total', 'Hour', 'Day', 'Week', 'Month', 'Archived') as $period) {
     $data['footer'][$period.'Events'] = $footer_totals['event_totals'][$period]['events'];
     $data['footer'][$period.'EventDiskSpace'] = human_filesize($footer_totals['event_totals'][$period]['diskspace']);
+
+    // Generate filter querystring for footer (include monitor filter if monitors are filtered)
+    $filter = $eventCountsFooter[$period]['filter'];
+    if (count($monitor_ids) > 0) {
+      $filter = addFilterTerm(
+        $filter,
+        count($filter['Query']['terms']),
+        array('cnj' => 'and', 'attr' => 'Monitor', 'op' => 'IN', 'val' => implode(',', $monitor_ids))
+      );
+    }
+    parseFilter($filter);
+    $data['footer'][$period.'FilterQuery'] = $filter['querystring'];
   }
   
   return $data;
