@@ -6,7 +6,7 @@ function MonitorStream(monitorData) {
   this.id = monitorData.id;
   this.name = monitorData.name;
   this.started = false;
-  this.muted = false;
+  this.muted = (currentView == 'watch') ? !!getCookie('zmWatchMuted') : true;
   this.connKey = monitorData.connKey;
   this.genConnKey = function() {
     return (Math.floor((Math.random() * 999999) + 1)).toLocaleString('en-US', {minimumIntegerDigits: 6, useGrouping: false});
@@ -338,6 +338,12 @@ function MonitorStream(monitorData) {
     if (statusEl) statusEl.innerText = '';
   };
 
+  this.copyAllAttributes = function(fromEl, toEl) {
+    for (const attr of fromEl.attributes) {
+      toEl.setAttribute(attr.name, attr.value);
+    }
+  };
+
   /*
   * streamChannel = 0 || Primary; 1 || Secondary.
   */
@@ -358,10 +364,9 @@ function MonitorStream(monitorData) {
 
         const old_stream = this.getElement();
         const stream = this.element = document.createElement('video-stream');
-        stream.id = old_stream.id; // should be liveStream+id
-        stream.style = old_stream.style; // Copy any applied styles
+        this.copyAllAttributes(old_stream, stream);
         stream.background = true; // We do not use the document hiding/showing analysis from "video-rtc.js", because we have our own analysis
-        stream.muted = this.muted;
+        //stream.muted = this.muted;
         const Go2RTCModUrl = url;
         const webrtcUrl = Go2RTCModUrl;
         this.currentChannelStream = (streamChannel == 'default') ? ((this.RTSP2WebStream == 'Secondary') ? 1 : 0) : streamChannel;
@@ -378,8 +383,9 @@ function MonitorStream(monitorData) {
         if (-1 != this.player.indexOf('_')) {
           stream.mode = this.player.substring(this.player.indexOf('_')+1);
         }
-        const video_el = document.querySelector('video');
+        const video_el = document.querySelector('#liveStream'+this.id+' video');
         if (video_el) {
+          video_el.muted = this.muted;
           video_el.addEventListener('play', (e) => {
             this.createVolumeSlider();
           }, this);
@@ -436,7 +442,7 @@ function MonitorStream(monitorData) {
           // replace with new video tag.
           const stream_container = stream.parentNode;
           const new_stream = this.element = document.createElement('video');
-          new_stream.id = stream.id; // should be liveStream+id
+          this.copyAllAttributes(stream, new_stream);
           new_stream.setAttribute("autoplay", "");
           new_stream.setAttribute("muted", this.muted);
           new_stream.setAttribute("playsinline", "");
@@ -506,8 +512,7 @@ function MonitorStream(monitorData) {
       // replace with new img tag.
       const stream_container = stream.parentNode;
       const new_stream = this.element = document.createElement('img');
-      new_stream.id = stream.id; // should be liveStream+id
-      new_stream.style = stream.style; // Copy any applied styles
+      this.copyAllAttributes(stream, new_stream);
       stream.remove();
       stream_container.appendChild(new_stream);
       stream = new_stream;
@@ -683,6 +688,7 @@ function MonitorStream(monitorData) {
       // Make zms exit, sometimes zms doesn't receive SIGPIPE, so try to send QUIT
       this.streamCommand(CMD_QUIT);
       this.connKey = null;
+      this.started = false;
     }
     // Kill and stop share a lot of the same code... so just call stop
     this.stop();
@@ -811,24 +817,27 @@ function MonitorStream(monitorData) {
     const mid = this.id;
     const audioStream = el.target;
     const volumeSlider = this.getVolumeSlider(mid);
-    const iconMute = this.getIconMute(mid);
     if (volumeSlider.allowSetValue) {
       if (audioStream.muted === true) {
-        iconMute.innerHTML = 'volume_off';
+        this.changeStateIconMute(mid, 'off');
         volumeSlider.classList.add('noUi-mute');
       } else {
-        iconMute.innerHTML = 'volume_up';
+        this.changeStateIconMute(mid, 'on');
         volumeSlider.classList.remove('noUi-mute');
       }
-      volumeSlider.noUiSlider.set(audioStream.volume * 100);
+      if (volumeSlider) {
+        volumeSlider.noUiSlider.set(audioStream.volume * 100);
+      }
     }
 
     if (currentView != 'montage') {
       setCookie('zmWatchMuted', audioStream.muted);
       setCookie('zmWatchVolume', parseInt(audioStream.volume * 100));
     }
-    volumeSlider.setAttribute('data-muted', audioStream.muted);
-    volumeSlider.setAttribute('data-volume', parseInt(audioStream.volume * 100));
+    if (volumeSlider) {
+      volumeSlider.setAttribute('data-muted', audioStream.muted);
+      volumeSlider.setAttribute('data-volume', parseInt(audioStream.volume * 100));
+    }
   };
 
   this.createVolumeSlider = function() {
@@ -836,7 +845,7 @@ function MonitorStream(monitorData) {
     const volumeSlider = this.getVolumeSlider(mid);
     const iconMute = this.getIconMute(mid);
     const audioStream = this.getAudioStream(mid);
-    if (!volumeSlider) return;
+    if (!volumeSlider || !audioStream) return;
     const defaultVolume = (volumeSlider.getAttribute("data-volume") || 50);
     if (volumeSlider.noUiSlider) volumeSlider.noUiSlider.destroy();
 
@@ -902,40 +911,67 @@ function MonitorStream(monitorData) {
     }
   };
 
+  /*
+  * volume: on || off
+  */
+  this.changeStateIconMute = function(mid, volume) {
+    const iconMute = this.getIconMute(mid);
+    if (iconMute) {
+      iconMute.innerHTML = (volume == 'on')? 'volume_up' : 'volume_off';
+    }
+    return iconMute;
+  };
+
+  /*
+  * volume: on || off
+  */
+  this.changeVolumeSlider = function(mid, volume) {
+    const volumeSlider = this.getVolumeSlider(mid);
+    if (volumeSlider) {
+      if (volume == 'on') {
+        volumeSlider.classList.remove('noUi-mute');
+      } else if (volume == 'off') {
+        volumeSlider.classList.add('noUi-mute');
+      }
+    }
+    return volumeSlider;
+  };
+
   /*
   * mode: switch, on, off
   */
   this.controlMute = function(mode = 'switch') {
-    if (mode=='switch') {
-      this.muted = !this.muted;
-    } else if (mode=='on') {
-      this.muted = true;
-    } else if (mode=='off') {
-      this.muted = false;
-    } else {
-      console.log("Invalid value for mode", mode);
-    }
     const mid = this.id;
-
+    let volumeSlider;
     const audioStream = this.getAudioStream(mid);
-    if (audioStream) {
-      audioStream.muted = this.muted;
-      console.log("Setting muted for ", mid, " to ", this.muted, "stream value is", audioStream.muted);
-    } else {
-      console.log("No audiostream! in controlMute");
+    if (!audioStream) {
+      console.log(`No audiostream! in controlMute for monitor ID=${mid}`);
+      return;
     }
-
-    const iconMute = this.getIconMute(mid);
-    if (!iconMute) return;
-    const volumeSlider = this.getVolumeSlider(mid);
-
-    if (!this.muted) {
-      iconMute.innerHTML = 'volume_up';
-      volumeSlider.classList.add('noUi-mute');
-      if (audioStream) audioStream.volume = volumeSlider.noUiSlider.get() / 100;
-    } else {
-      iconMute.innerHTML = 'volume_off';
-      volumeSlider.classList.remove('noUi-mute');
+    if (mode=='switch') {
+      if (audioStream.muted) {
+        audioStream.muted = this.muted = false;
+        this.changeStateIconMute(mid, 'on');
+        volumeSlider = this.changeVolumeSlider(mid, 'on');
+        if (volumeSlider) {
+          audioStream.volume = volumeSlider.noUiSlider.get() / 100;
+        }
+      } else {
+        audioStream.muted = this.muted = true;
+        this.changeStateIconMute(mid, 'off');
+        this.changeVolumeSlider(mid, 'off');
+      }
+    } else if (mode=='on') {
+      audioStream.muted = this.muted = true;
+      this.changeStateIconMute(mid, 'off');
+      this.changeVolumeSlider(mid, 'off');
+    } else if (mode=='off') {
+      audioStream.muted = this.muted = false;
+      this.changeStateIconMute(mid, 'on');
+      volumeSlider = this.changeVolumeSlider(mid, 'on');
+      if (volumeSlider) {
+        audioStream.volume = volumeSlider.noUiSlider.get() / 100;
+      }
     }
   };
 
