@@ -65,6 +65,7 @@ $SLANG = array(
     'AddMonitorDisabled'    => 'Your user is not allowed to add a new monitor',
     'AddNewServer'          => 'Add New Server',
     'AddNewStorage'         => 'Add New Storage',
+    'AddNewRole'            => 'Add New Role',
     'AddNewUser'            => 'Add New User',
     'AddNewZone'            => 'Add New Zone',
     'AlarmBrFrames'         => 'Alarm<br/>Frames',
@@ -82,6 +83,7 @@ $SLANG = array(
     'APIEnabled'            => 'API Enabled',
     'ApplyingStateChange'   => 'Applying State Change',
     'ArchArchived'          => 'Archived Only',
+    'Assigned Users'        => 'Assigned Users',
     'ArchUnarchived'        => 'Unarchived Only',
     'AreaUnits'             => 'Area (px/%)',
     'AttrAlarmFrames'       => 'Alarm Frames',
@@ -270,6 +272,7 @@ $SLANG = array(
     'EditLayout'            => 'Edit Layout',
     'EnableAlarms'          => 'Enable Alarms',
     'EnterNewFilterName'    => 'Enter new filter name',
+    'Enter password for QR code' => 'Enter password for QR code',
     'ErrorBrackets'         => 'Error, please check you have an equal number of opening and closing brackets',
     'ErrorValidValue'       => 'Error, please check that all terms have a valid value',
     'Etc'                   => 'etc',
@@ -328,6 +331,7 @@ $SLANG = array(
     'MotionFrameSkip'       => 'Motion Frame Skip',
     'GenerateVideo'         => 'Generate Video',
     'GeneratingVideo'       => 'Generating Video',
+    'Generate QR Code'      => 'Generate QR Code',
     'GetCurrentLocation'    => 'Get Current Location',
     'GoToZoneMinder'        => 'Go to ZoneMinder.com',
     'HasFocusSpeed'         => 'Has Focus Speed',
@@ -435,6 +439,7 @@ $SLANG = array(
     'MustSupplyUsername'    => 'You must supply a username',
     'NewGroup'              => 'New Group',
     'NewLabel'              => 'New Label',
+    'NewRole'               => 'New Role',
     'NewPassword'           => 'New Password',
     'NewState'              => 'New State',
     'NewUser'               => 'New User',
@@ -443,9 +448,12 @@ $SLANG = array(
     'NoDetectedProfiles'    => 'No Detected Profiles',
     'NoFramesRecorded'      => 'There are no frames recorded for this event',
     'NoGroup'               => 'No Group',
+    'NoRole'                => 'No Role (Direct Permissions Only)',
+    'No users assigned to this role' => 'No users assigned to this role',
     'NoneAvailable'         => 'None available',
     'NoSavedFilters'        => 'No Saved Filters',
     'NoStatisticsRecorded'  => 'There are no statistics recorded for this event/frame',
+    'Any Tag'               => 'Any Tag',
     'No Tag'                => 'No Tag',
     'NumPresets'            => 'Num Presets',
     'OnvifProbe'            => 'ONVIF',
@@ -495,10 +503,12 @@ $SLANG = array(
     'PlayAll'               => 'Play All',
     'PlayCycle'             => 'Play Cycle',
     'PlayerDisabledInMonitorSettings'  => 'The player is disabled in the monitor settings.',
+    'Please enter a password' => 'Please enter a password',
     'PleaseWait'            => 'Please Wait',
     'PostEventImageBuffer'  => 'Post Event Image Count',
     'PreEventImageBuffer'   => 'Pre Event Image Count',
     'PreserveAspect'        => 'Preserve Aspect Ratio',
+    'PreviewRate'           => 'Preview Rate',
     'PreviousMonitor'       => 'Previous Monitor',
     'PrivacyAbout'          => 'About',
     'PrivacyAboutText'      => 'Since 2002, ZoneMinder has been the premier free and open-source Video Management System (VMS) solution for Linux platforms. ZoneMinder is supported by the community and is managed by those who choose to volunteer their spare time to the project. The best way to improve ZoneMinder is to get involved.',
@@ -559,6 +569,9 @@ $SLANG = array(
     'ReturnDelay'           => 'Return Delay',
     'ReturnLocation'        => 'Return Location',
     'RevokeAllTokens'       => 'Revoke All Tokens',
+    'Role'                  => 'Role',
+    'Role Details'          => 'Role Details',
+    'Roles'                 => 'Roles',
     'RotateLeft'            => 'Rotate Left',
     'RotateRight'           => 'Rotate Right',
     'RTSPTransport'         => 'RTSP Transport Protocol',
@@ -573,6 +586,7 @@ $SLANG = array(
     'SaveAs'                => 'Save as',
     'SaveFilter'            => 'Save Filter',
     'SaveJPEGs'             => 'Save JPEGs',
+    'Scan this QR code with the zmNg app to add this profile' => 'Scan this QR code with the zmNg app to add this profile',
     'Sectionlength'         => 'Section length',
     'SelectMonitors'        => 'Select Monitors',
     'SelectFormat'          => 'Select Format',
@@ -582,6 +596,8 @@ $SLANG = array(
     'SetPreset'             => 'Set Preset',
     'ShowFilterWindow'      => 'Show Filter Window',
     'ShowTimeline'          => 'Show Timeline',
+    'Show Analysis'         => 'Show Analysis',
+    'Showing Analysis'      => 'Showing Analysis',
     'SignalCheckColour'     => 'Signal Check Colour',
     'SignalCheckPoints'     => 'Signal Check Points',
     'SkinDescription'       => 'Change the skin for this session',
@@ -677,6 +693,8 @@ $SLANG = array(
     'ZoneExtendAlarmFrames' => 'Extend Alarm Frame Count',
     'ZoomIn'                => 'Zoom In',
     'ZoomOut'               => 'Zoom Out',
+    'zmNg Mobile App QR Code' => 'zmNg Mobile App QR Code',
+    'Generate a QR code to quickly set up this user in the zmNg mobile app. Enter the user\'s password to generate the QR code.' => 'Generate a QR code to quickly set up this user in the zmNg mobile app. Enter the user\'s password to generate the QR code.',
 // language names translation
     'es_la' => 'Spanish Latam',
     'es_CR' => 'Spanish Costa Rica',
