@@ -18,28 +18,40 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 
-function addFilterSelect($name, $options) {
-  global $view;
-  // Use monitorFilterOnChange on console view for AJAX refresh, submitThisForm elsewhere
-  $onChangeFunction = ($view == 'console') ? 'monitorFilterOnChange' : 'submitThisForm';
-  
-  // Get selected value from cookie only
+// Helper function to get filter value from request or cookie
+// We get from request so that we can use bookmarks
+// Otherwise everything is done in js in cookies.
+function getFilterSelection($name) {
   $selectedValue = '';
-  if (isset($_COOKIE['zmFilter_'.$name])) {
-    $cookieValue = $_COOKIE['zmFilter_'.$name];
+  $cookieValue = '';
+  $cookieName = 'zmFilter_'.$name;
+
+  if (isset($_REQUEST[$name])) {
+    $selectedValue = $_REQUEST[$name];
+    $cookieValue = json_encode($selectedValue);
+    if (!isset($_COOKIE[$cookieName]) or ($_COOKIE[$cookieName] != $cookieValue)) {
+      zm_setcookie($cookieName, $cookieValue);
+    }
+  } else if (isset($_COOKIE[$cookieName])) {
+    $cookieValue = $_COOKIE[$cookieName];
     if ($cookieValue && $cookieValue !== '') {
       // Try to decode JSON for array values
       $decoded = json_decode($cookieValue, true);
       $selectedValue = ($decoded !== null) ? $decoded : $cookieValue;
     }
   }
+  return $selectedValue;
+}
+
+function addFilterSelect($name, $options, $selectedValue=null) {
+  if ($selectedValue == null) $selectedValue = getFilterSelection($name);
   
   $html = '<span class="term '.$name.'Filter"><label>'.translate($name).'</label>';
   $html .= '<span class="term-value-wrapper">';
   $html .= htmlSelect($name.'[]', $options,
     $selectedValue,
       array(
-        'data-on-change'=>$onChangeFunction,
+        'data-on-change-this'=>'monitorFilterOnChange',
         'class'=>'chosen',
         'multiple'=>'multiple',
         'data-placeholder'=>'All',
@@ -70,22 +82,6 @@ function buildMonitorsFilters() {
   global $user, $Servers, $view;
   require_once('includes/Monitor.php');
   
-  // Use monitorFilterOnChange on console view for AJAX refresh, submitThisForm elsewhere
-  $onChangeFunction = ($view == 'console') ? 'monitorFilterOnChange' : 'submitThisForm';
-
-  // Helper function to get filter value from cookie
-  function getFilterFromCookie($var) {
-    $cookieName = 'zmFilter_'.$var;
-    if (isset($_COOKIE[$cookieName])) {
-      $cookieValue = $_COOKIE[$cookieName];
-      if ($cookieValue && $cookieValue !== '') {
-        // Try to decode JSON for array values
-        $decoded = json_decode($cookieValue, true);
-        return ($decoded !== null) ? $decoded : $cookieValue;
-      }
-    }
-    return null;
-  }
 
   $storage_areas = ZM\Storage::find();
   $StorageById = array();
@@ -114,19 +110,13 @@ function buildMonitorsFilters() {
     }
 
     if (count($GroupsById)) {
-      $html .= '<span class="term" id="groupControl"><label>'. translate('Group') .'</label>';
-      $html .= '<span class="term-value-wrapper">';
-      # This will end up with the group_id of the deepest selection
-      $group_id = getFilterFromCookie('GroupId');
-      $html .= ZM\Group::get_group_dropdown($view);
+      $group_id = getFilterSelection('GroupId');
+      $html .= addFilterSelect('GroupId', ZM\Group::get_dropdown_options(), $group_id);
       $groupSql = ZM\Group::get_group_sql($group_id);
-      $html .= addButtonResetForFilterSelect('GroupId[]');
-      $html .= '</span>';
-      $html .= '</span>';
     }
   }
 
-  $selected_monitor_ids = getFilterFromCookie('MonitorId');
+  $selected_monitor_ids = getFilterSelection('MonitorId');
   if (!$selected_monitor_ids) {
     $selected_monitor_ids = array();
   } else if (!is_array($selected_monitor_ids)) {
@@ -139,7 +129,7 @@ function buildMonitorsFilters() {
   if ( $groupSql )
     $conditions[] = $groupSql;
   foreach ( array('ServerId','StorageId','Status','Capturing','Analysing','Recording') as $filter ) {
-    $filterValue = getFilterFromCookie($filter);
+    $filterValue = getFilterSelection($filter);
     if ( $filterValue ) {
       if ( is_array($filterValue) ) {
         $conditions[] = '`'.$filter . '` IN ('.implode(',', array_map(function(){return '?';}, $filterValue)).')';
@@ -157,23 +147,23 @@ function buildMonitorsFilters() {
     $values = array_merge($values, $ids);
   }
 
-  $monitorNameValue = getFilterFromCookie('MonitorName');
+  $monitorNameValue = getFilterSelection('MonitorName');
   $html .= '<span class="term MonitorNameFilter"><label>'.translate('Name').'</label>';
   $html .= '<span class="term-value-wrapper">';
-  $html .= '<input type="text" name="MonitorName" value="'.($monitorNameValue ? validHtmlStr($monitorNameValue) : '').'" placeholder="'.translate('text or regular expression').'"/></span>';
+  $html .= '<input type="text" name="MonitorName" value="'.($monitorNameValue ? validHtmlStr($monitorNameValue) : '').'" placeholder="'.translate('text or regular expression').'" data-on-input="monitorFilterOnChange"/></span>';
   $html .= '</span>'.PHP_EOL;
 
-  $html .= addFilterSelect('Capturing', array('None'=>translate('None'), 'Always'=>translate('Always'), 'OnDemand'=>translate('On Demand')));
-  $html .= addFilterSelect('Analysing', array('None'=>translate('None'), 'Always'=>translate('Always')));
-  $html .= addFilterSelect('Recording', array('None'=>translate('None'), 'OnMotion'=>translate('On Motion'),'Always'=>translate('Always')));
+  $html .= addFilterSelect('Capturing', ['None'=>translate('None'), 'Always'=>translate('Always'), 'OnDemand'=>translate('On Demand')]);
+  $html .= addFilterSelect('Analysing', ['None'=>translate('None'), 'Always'=>translate('Always')]);
+  $html .= addFilterSelect('Recording', ['None'=>translate('None'), 'OnMotion'=>translate('On Motion'),'Always'=>translate('Always')]);
 
   if ( count($ServersById) > 1 ) {
     $html .= '<span class="term ServerFilter"><label>'. translate('Server').'</label>';
     $html .= '<span class="term-value-wrapper">';
     $html .= htmlSelect('ServerId[]', $ServersById,
-      getFilterFromCookie('ServerId') ?: '',
+      getFilterSelection('ServerId') ?: '',
       array(
-        'data-on-change'=>$onChangeFunction,
+        'data-on-change-this'=>'monitorFilterOnChange',
         'class'=>'chosen',
         'multiple'=>'multiple',
         'data-placeholder'=>'All',
@@ -188,9 +178,9 @@ function buildMonitorsFilters() {
     $html .= '<span class="term StorageFilter"><label>'.translate('Storage').'</label>';
     $html .= '<span class="term-value-wrapper">';
     $html .= htmlSelect('StorageId[]', $StorageById,
-      getFilterFromCookie('StorageId') ?: '',
+      getFilterSelection('StorageId') ?: '',
       array(
-        'data-on-change'=>$onChangeFunction,
+        'data-on-change-this'=>'monitorFilterOnChange',
         'class'=>'chosen',
         'multiple'=>'multiple',
         'data-placeholder'=>'All',
@@ -209,9 +199,9 @@ function buildMonitorsFilters() {
     );
   $html .= '<span class="term-value-wrapper">';
   $html .= htmlSelect( 'Status[]', $status_options,
-    getFilterFromCookie('Status') ?: '',
+    getFilterSelection('Status') ?: '',
     array(
-      'data-on-change'=>$onChangeFunction,
+      'data-on-change-this'=>'monitorFilterOnChange',
       'class'=>'chosen',
       'multiple'=>'multiple',
       'data-placeholder'=>'All'
@@ -220,7 +210,7 @@ function buildMonitorsFilters() {
   $html .= '</span>';
   $html .= '</span>';
 
-  $sourceValue = getFilterFromCookie('Source');
+  $sourceValue = getFilterSelection('Source');
   $html .= '<span class="term SourceFilter"><label>'.translate('Source').'</label>';
   $html .= '<span class="term-value-wrapper">';
   $html .= '<input type="text" name="Source" value="'.($sourceValue ? validHtmlStr($sourceValue) : '').'" placeholder="'.translate('text or regular expression').'"/>';
@@ -268,7 +258,7 @@ function buildMonitorsFilters() {
       continue;
     }
 
-    $monitorNameFilter = getFilterFromCookie('MonitorName');
+    $monitorNameFilter = getFilterSelection('MonitorName');
     if ( $monitorNameFilter ) {
       $Monitor = new ZM\Monitor($monitors[$i]);
       ini_set('track_errors', 'on');
@@ -286,7 +276,7 @@ function buildMonitorsFilters() {
       }
     }
 
-    $sourceFilter = getFilterFromCookie('Source');
+    $sourceFilter = getFilterSelection('Source');
     if ( $sourceFilter ) {
       $Monitor = new ZM\Monitor($monitors[$i]);
       ini_set('track_errors', 'on');
@@ -321,7 +311,7 @@ function buildMonitorsFilters() {
   $html .= '<span class="term-value-wrapper">';
   $html .= htmlSelect('MonitorId[]', $monitors_dropdown, $selected_monitor_ids,
     array(
-      'data-on-change'=>$onChangeFunction,
+      'data-on-change-this'=>'monitorFilterOnChange',
       'class'=>'chosen',
       'multiple'=>'multiple',
       'data-placeholder'=>'All',
