@@ -153,15 +153,6 @@ if ((!$replayMode) or !$replayModes[$replayMode]) {
 $video_tag = ($codec == 'MP4') || 
   ((false !== strpos($Event->DefaultVideo(), 'h264') || false !== strpos($Event->DefaultVideo(), 'av1')) && ($codec === 'auto'));
 
-// videojs zoomrotate only when direct recording
-$Zoom = 1;
-$Rotation = 0;
-if ($monitor->VideoWriter() == '2') {
-# Passthrough
-  $Rotation = $Event->Orientation();
-  if (in_array($Event->Orientation(),array('90','270')))
-    $Zoom = $Event->Height()/$Event->Width();
-}
 
 // These are here to figure out the next/prev event, however if there is no filter, then default to one that specifies the Monitor
 if ( !isset($_REQUEST['filter']) ) {
@@ -331,21 +322,39 @@ if (file_exists($Event->Path().'/objdetect.jpg')) {
 <?php
 if ($video_tag) {
 ?>
-                  <video autoplay id="videoobj" class="video-js vjs-default-skin"
-                    style="transform: matrix(1, 0, 0, 1, 0, 0);"
+                  <video id="videoobj" class="video-js"
                    <?php echo $scale ? 'width="'.reScale($Event->Width(), $scale).'"' : '' ?>
                    <?php echo $scale ? 'height="'.reScale($Event->Height(), $scale).'"' : '' ?>
-                    data-setup='{ "controls": true, "autoplay": true, "preload": "auto", "playbackRates": [ <?php echo implode(',',
-                      array_map(function($r){return $r/100;},
-                        array_filter(
-                          array_keys($rates),
-                          function($r){return $r >= 0 ? true : false;}
-                        ))) ?>], "plugins": { "zoomrotate": { "zoom": "<?php echo $Zoom ?>"}}}'
+                    controls autoplay preload="auto"
                   >
                   <source src="<?php echo $Event->getStreamSrc(array('mode'=>'mp4','format'=>'h264'),'&amp;'); ?>" type="video/mp4">
                   <track id="monitorCaption" kind="captions" label="English" srclang="en" src='data:plain/text;charset=utf-8,"WEBVTT\n\n 00:00:00.000 --> 00:00:01.000 ZoneMinder"' default/>
                   Your browser does not support the video tag.
                   </video>
+                  <script nonce="<?php echo $cspNonce; ?>">
+                    document.addEventListener('DOMContentLoaded', function() {
+                      if (typeof videojs === 'undefined') {
+                        console.error('videojs is not loaded');
+                        return;
+                      }
+                      var rates = [<?php echo implode(',',
+                        array_map(function($r){return $r/100;},
+                          array_filter(
+                            array_keys($rates),
+                            function($r){return $r >= 0 ? true : false;}
+                          ))) ?>];
+                      var player = videojs('videoobj', {
+                        controls: true,
+                        autoplay: true,
+                        preload: 'auto',
+                        playbackRates: rates
+                      });
+                      player.zoomrotate({
+                        zoom: 1,
+                        rotate: 0
+                      });
+                    });
+                  </script>
 <?php
 } else {
   if ( (ZM_WEB_STREAM_METHOD == 'mpeg') && ZM_MPEG_LIVE_FORMAT ) {
@@ -452,8 +461,7 @@ if ($video_tag) {
     
   </div><!--page-->
   <link href="skins/<?php echo $skin ?>/js/video-js.css" rel="stylesheet">
-  <link href="skins/<?php echo $skin ?>/js/video-js-skin.css" rel="stylesheet">
-  <script src="skins/<?php echo $skin ?>/js/video.js"></script>
+  <script src="skins/<?php echo $skin ?>/js/video.min.js"></script>
   <script src="./js/videojs.zoomrotate.js"></script>
 <?php
   echo output_link_if_exists(array('css/base/zones.css'));
