@@ -440,11 +440,14 @@ echo $monitor->getStreamHTML($options);
               <i class="material-icons md-18">zoom_out</i>
               </button>
           </div><!--dvrControls-->
-          <div class="buttons" id="extButton"> 
+          <div class="buttons" id="extButton">
+            <button type="button" id="analyseBtn" class="btn btn-secondary" title="<?php echo translate('Show Analysis') ?>" data-on-click="toggleAnalyseFrames">
+            <i class="material-icons md-18">assessment</i>
+            </button>
             <button type="button" id="fullscreenBtn" title="<?php echo translate('Fullscreen') ?>" class="avail" data-on-click="watchFullscreen">
             <i class="material-icons md-18">fullscreen</i>
             </button>
-            <button type="button" id="allEventsBtn" title="<?php echo translate('All Events') ?>" class="avail" data-on-click="watchAllEvents"><?php echo translate('All Events') ?> 
+            <button type="button" id="allEventsBtn" title="<?php echo translate('All Events') ?>" class="avail" data-on-click="watchAllEvents"><?php echo translate('All Events') ?>
             </button>
 <?php 
 $volume = isset($_REQUEST['volume']) ? validInt($_REQUEST['volume']) :
